@@ -898,7 +898,7 @@ class KEuphoriaSaverInterface : public KScreenSaverInterface
 
 public:
     virtual KAboutData* aboutData() {
-        return new KAboutData( "keuphoria.kss", 0, ki18n( "Euphoria" ), "1.0", ki18n( "Euphoria" ) );
+        return new KAboutData( "keuphoria.kss", "klock", ki18n( "Euphoria" ), "1.0", ki18n( "Euphoria" ) );
     }
 
 
@@ -1032,6 +1032,7 @@ KEuphoriaSetup::KEuphoriaSetup( QWidget* parent )
         QPalette palette;
         palette.setColor( preview->backgroundRole(), Qt::black );
         preview->setPalette( palette );
+	preview->setAutoFillBackground(true);
     }
     preview->show();    // otherwise saver does not get correct size
     _saver = new KEuphoriaScreenSaver( preview->winId() );
