@@ -70,7 +70,7 @@ class KRotationSaverInterface : public KScreenSaverInterface
       virtual KAboutData* aboutData()
       {
          return new KAboutData(
-            "krotation.kss", 0,
+            "krotation.kss", "klock",
             ki18n("Simulation of a force free rotating asymmetric body"),
             KROTATION_VERSION,
             ki18n("Simulation of a force free rotating asymmetric body"));
@@ -723,42 +723,49 @@ const unsigned int KRotationSaver::sm_deltaT                 = 20;
 //-----------------------------------------------------------------------------
 
 KRotationSetup::KRotationSetup(QWidget* parent)
-   : QDialog(parent)
+   : KDialog(parent)
 {
-   setupUi(this);
+   setCaption(i18n( "KRotation Setup" ));
+   setButtons(Ok|Cancel|Help);
+   setDefaultButton(Ok);
+   setButtonText( Help, i18n( "A&bout" ) );
+   QWidget *main = new QWidget(this);
+   setMainWidget(main);
+   cfg = new RotationWidget();
+   cfg->setupUi( main );
 
    // the dialog should block, no other control center input should be possible
    // until the dialog is closed
    setModal(true);
 
-   m_lengthEdit->setValidator(
+   cfg->m_lengthEdit->setValidator(
       new QDoubleValidator(
          KRotationSaver::sm_traceLengthSecondsLimitLower,
          KRotationSaver::sm_traceLengthSecondsLimitUpper,
-         3, m_lengthEdit));
-   m_LzEdit->setValidator(
+         3, cfg->m_lengthEdit));
+   cfg->m_LzEdit->setValidator(
       new QDoubleValidator(
          KRotationSaver::sm_LzLimitLower,
          KRotationSaver::sm_LzLimitUpper,
-         3, m_LzEdit));
-   m_thetaEdit->setValidator(
+         3, cfg->m_LzEdit));
+   cfg->m_thetaEdit->setValidator(
       new QDoubleValidator(
          KRotationSaver::sm_initEulerThetaLimitLower,
          KRotationSaver::sm_initEulerThetaLimitUpper,
-         3, m_thetaEdit));
+         3, cfg->m_thetaEdit));
 
    // set tool tips of editable fields
-   m_lengthEdit->setToolTip(
+   cfg->m_lengthEdit->setToolTip(
       ki18n("Length of traces in seconds of visibility.\nValid values from %1 to %2.")
       .subs(KRotationSaver::sm_traceLengthSecondsLimitLower, 0, 'f', 2)
       .subs(KRotationSaver::sm_traceLengthSecondsLimitUpper, 0, 'f', 2)
       .toString());
-   m_LzEdit->setToolTip(
+   cfg->m_LzEdit->setToolTip(
       ki18n("Angular momentum in z direction in arbitrary units.\nValid values from %1 to %2.")
       .subs(KRotationSaver::sm_LzLimitLower, 0, 'f', 2)
       .subs(KRotationSaver::sm_LzLimitUpper, 0, 'f', 2)
       .toString());
-   m_thetaEdit->setToolTip(
+   cfg->m_thetaEdit->setToolTip(
       ki18n("Gravitational constant in arbitrary units.\nValid values from %1 to %2.")
       .subs(KRotationSaver::sm_initEulerThetaLimitLower, 0, 'f', 2)
       .subs(KRotationSaver::sm_initEulerThetaLimitUpper, 0, 'f', 2)
@@ -766,49 +773,50 @@ KRotationSetup::KRotationSetup(QWidget* parent)
 
    // setting the background of m_preview widget is not necessary, it's content
    // is overlayed with the embedded GL widget anyway
-   m_preview->show();    // otherwise saver does not get correct size initially
+   cfg->m_preview->show();    // otherwise saver does not get correct size initially
 
    // create screen saver and give it the WinID of the preview area in which it
    // will be embedded
-   m_saver = new KRotationSaver(m_preview->winId());
+   m_saver = new KRotationSaver(cfg->m_preview->winId());
 
    // read settings from saver and update GUI elements with these values, saver
    // has read settings in its constructor
 
    // set editable fields with stored values as defaults
-   m_xTrace->setChecked(m_saver->traceFlag(0));
-   m_yTrace->setChecked(m_saver->traceFlag(1));
-   m_zTrace->setChecked(m_saver->traceFlag(2));
-   m_randTraces->setChecked(m_saver->randomTraces());
+   cfg->m_xTrace->setChecked(m_saver->traceFlag(0));
+   cfg->m_yTrace->setChecked(m_saver->traceFlag(1));
+   cfg->m_zTrace->setChecked(m_saver->traceFlag(2));
+   cfg->m_randTraces->setChecked(m_saver->randomTraces());
    QString text;
    text.setNum(m_saver->traceLengthSeconds());
-   m_lengthEdit->setText(text);
+   cfg->m_lengthEdit->setText(text);
    text.setNum(m_saver->Lz());
-   m_LzEdit->setText(text);
+   cfg->m_LzEdit->setText(text);
    text.setNum(m_saver->initEulerTheta());
-   m_thetaEdit->setText(text);
+   cfg->m_thetaEdit->setText(text);
 
    // if the preview area is resized it emits the resized() event which is
    // caught by m_saver.  The embedded GLArea is resized to fit into the preview
    // area.
-   connect(m_preview,   SIGNAL(resized(QResizeEvent*)),
+   connect(cfg->m_preview,   SIGNAL(resized(QResizeEvent*)),
            m_saver,     SLOT(resizeGlArea(QResizeEvent*)));
 
-   connect(m_okButton,    SIGNAL(clicked()),            this, SLOT(okButtonClickedSlot()));
-   connect(m_aboutButton, SIGNAL(clicked()),            this, SLOT(aboutButtonClickedSlot()));
+   connect(this,    SIGNAL(okClicked()),            this, SLOT(okButtonClickedSlot()));
+   connect(this, SIGNAL(helpClicked()),            this, SLOT(aboutButtonClickedSlot()));
 
-   connect(m_xTrace,      SIGNAL(toggled(bool)),        this, SLOT(xTraceToggled(bool)));
-   connect(m_randTraces,  SIGNAL(toggled(bool)),        this, SLOT(randomTracesToggled(bool)));
-   connect(m_yTrace,      SIGNAL(toggled(bool)),        this, SLOT(yTraceToggled(bool)));
-   connect(m_zTrace,      SIGNAL(toggled(bool)),        this, SLOT(zTraceToggled(bool)));
-   connect(m_lengthEdit,  SIGNAL(textChanged(QString)), this, SLOT(lengthEnteredSlot(QString)));
-   connect(m_LzEdit,      SIGNAL(textChanged(QString)), this, SLOT(LzEnteredSlot(QString)));
-   connect(m_thetaEdit,   SIGNAL(textChanged(QString)), this, SLOT(thetaEnteredSlot(QString)));
+   connect(cfg->m_xTrace,      SIGNAL(toggled(bool)),        this, SLOT(xTraceToggled(bool)));
+   connect(cfg->m_randTraces,  SIGNAL(toggled(bool)),        this, SLOT(randomTracesToggled(bool)));
+   connect(cfg->m_yTrace,      SIGNAL(toggled(bool)),        this, SLOT(yTraceToggled(bool)));
+   connect(cfg->m_zTrace,      SIGNAL(toggled(bool)),        this, SLOT(zTraceToggled(bool)));
+   connect(cfg->m_lengthEdit,  SIGNAL(textChanged(QString)), this, SLOT(lengthEnteredSlot(QString)));
+   connect(cfg->m_LzEdit,      SIGNAL(textChanged(QString)), this, SLOT(LzEnteredSlot(QString)));
+   connect(cfg->m_thetaEdit,   SIGNAL(textChanged(QString)), this, SLOT(thetaEnteredSlot(QString)));
 }
 
 KRotationSetup::~KRotationSetup()
 {
    delete m_saver;
+   delete cfg;
 }
 
 // Ok pressed - save settings and exit
@@ -853,9 +861,9 @@ void KRotationSetup::randomTracesToggled(bool state)
    if (!state)
    {
       // restore settings from gui if random traces are turned off
-      m_saver->setTraceFlag(0, m_xTrace->isChecked());
-      m_saver->setTraceFlag(1, m_yTrace->isChecked());
-      m_saver->setTraceFlag(2, m_zTrace->isChecked());
+      m_saver->setTraceFlag(0, cfg->m_xTrace->isChecked());
+      m_saver->setTraceFlag(1, cfg->m_yTrace->isChecked());
+      m_saver->setTraceFlag(2, cfg->m_zTrace->isChecked());
    }
 }
 void KRotationSetup::lengthEnteredSlot(const QString& s)
